@@ -11,12 +11,12 @@ from ...types import UNSET, Response, Unset
 
 def _get_kwargs(
     *,
-    search: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = 1,
 ) -> Dict[str, Any]:
     pass
 
     params: Dict[str, Any] = {}
-    params["search"] = search
+    params["page"] = page
 
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
@@ -59,12 +59,12 @@ def _build_response(
 def sync_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
-    search: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = 1,
 ) -> Response[List["GetGlobalConnectedRepositoriesResponse200Item"]]:
     """get connected repositories
 
     Args:
-        search (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):  Default: 1.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -75,7 +75,7 @@ def sync_detailed(
     """
 
     kwargs = _get_kwargs(
-        search=search,
+        page=page,
     )
 
     response = client.get_httpx_client().request(
@@ -88,12 +88,12 @@ def sync_detailed(
 def sync(
     *,
     client: Union[AuthenticatedClient, Client],
-    search: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = 1,
 ) -> Optional[List["GetGlobalConnectedRepositoriesResponse200Item"]]:
     """get connected repositories
 
     Args:
-        search (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):  Default: 1.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -105,19 +105,19 @@ def sync(
 
     return sync_detailed(
         client=client,
-        search=search,
+        page=page,
     ).parsed
 
 
 async def asyncio_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
-    search: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = 1,
 ) -> Response[List["GetGlobalConnectedRepositoriesResponse200Item"]]:
     """get connected repositories
 
     Args:
-        search (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):  Default: 1.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -128,7 +128,7 @@ async def asyncio_detailed(
     """
 
     kwargs = _get_kwargs(
-        search=search,
+        page=page,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -139,12 +139,12 @@ async def asyncio_detailed(
 async def asyncio(
     *,
     client: Union[AuthenticatedClient, Client],
-    search: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = 1,
 ) -> Optional[List["GetGlobalConnectedRepositoriesResponse200Item"]]:
     """get connected repositories
 
     Args:
-        search (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):  Default: 1.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -157,6 +157,6 @@ async def asyncio(
     return (
         await asyncio_detailed(
             client=client,
-            search=search,
+            page=page,
         )
     ).parsed
