@@ -1,8 +1,10 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
+from ..types import UNSET, Unset
+
 T = TypeVar("T", bound="AddUserJsonBody")
 
 
@@ -12,21 +14,21 @@ class AddUserJsonBody:
     Attributes:
         email (str):
         is_admin (bool):
-        username (str):
         operator (bool):
+        username (Union[Unset, str]):
     """
 
     email: str
     is_admin: bool
-    username: str
     operator: bool
+    username: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         email = self.email
         is_admin = self.is_admin
-        username = self.username
         operator = self.operator
+        username = self.username
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -34,10 +36,11 @@ class AddUserJsonBody:
             {
                 "email": email,
                 "is_admin": is_admin,
-                "username": username,
                 "operator": operator,
             }
         )
+        if username is not UNSET:
+            field_dict["username"] = username
 
         return field_dict
 
@@ -48,15 +51,15 @@ class AddUserJsonBody:
 
         is_admin = d.pop("is_admin")
 
-        username = d.pop("username")
-
         operator = d.pop("operator")
 
+        username = d.pop("username", UNSET)
+
         add_user_json_body = cls(
             email=email,
             is_admin=is_admin,
-            username=username,
             operator=operator,
+            username=username,
         )
 
         add_user_json_body.additional_properties = d
