@@ -14,15 +14,18 @@ class EditAutoInviteJsonBody:
     Attributes:
         operator (Union[Unset, bool]):
         invite_all (Union[Unset, bool]):
+        auto_add (Union[Unset, bool]):
     """
 
     operator: Union[Unset, bool] = UNSET
     invite_all: Union[Unset, bool] = UNSET
+    auto_add: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         operator = self.operator
         invite_all = self.invite_all
+        auto_add = self.auto_add
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -31,6 +34,8 @@ class EditAutoInviteJsonBody:
             field_dict["operator"] = operator
         if invite_all is not UNSET:
             field_dict["invite_all"] = invite_all
+        if auto_add is not UNSET:
+            field_dict["auto_add"] = auto_add
 
         return field_dict
 
@@ -41,9 +46,12 @@ class EditAutoInviteJsonBody:
 
         invite_all = d.pop("invite_all", UNSET)
 
+        auto_add = d.pop("auto_add", UNSET)
+
         edit_auto_invite_json_body = cls(
             operator=operator,
             invite_all=invite_all,
+            auto_add=auto_add,
         )
 
         edit_auto_invite_json_body.additional_properties = d
