@@ -6,11 +6,13 @@ class EditWorkspaceGitSyncConfigJsonBodyGitSyncSettingsRepositoriesItemExcludeTy
     FLOW = "flow"
     FOLDER = "folder"
     GROUP = "group"
+    KEY = "key"
     RESOURCE = "resource"
     RESOURCETYPE = "resourcetype"
     SCHEDULE = "schedule"
     SCRIPT = "script"
     SECRET = "secret"
+    SETTINGS = "settings"
     TRIGGER = "trigger"
     USER = "user"
     VARIABLE = "variable"
