@@ -44,7 +44,7 @@ class ExtendedJobsJobsItemType1:
         scheduled_for (Union[Unset, datetime.datetime]):
         script_path (Union[Unset, str]):
         script_hash (Union[Unset, str]):
-        args (Union[Unset, ExtendedJobsJobsItemType1Args]):
+        args (Union[Unset, ExtendedJobsJobsItemType1Args]): The arguments to pass to the script or flow
         logs (Union[Unset, str]):
         raw_code (Union[Unset, str]):
         canceled_by (Union[Unset, str]):
