@@ -1,9 +1,10 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
 from ..models.flow_module_value_2_type_7_type import FlowModuleValue2Type7Type
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="FlowModuleValue2Type7")
 
@@ -13,14 +14,18 @@ class FlowModuleValue2Type7:
     """
     Attributes:
         type (FlowModuleValue2Type7Type):
+        flow (Union[Unset, bool]):
     """
 
     type: FlowModuleValue2Type7Type
+    flow: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         type = self.type.value
 
+        flow = self.flow
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -28,6 +33,8 @@ class FlowModuleValue2Type7:
                 "type": type,
             }
         )
+        if flow is not UNSET:
+            field_dict["flow"] = flow
 
         return field_dict
 
@@ -36,8 +43,11 @@ class FlowModuleValue2Type7:
         d = src_dict.copy()
         type = FlowModuleValue2Type7Type(d.pop("type"))
 
+        flow = d.pop("flow", UNSET)
+
         flow_module_value_2_type_7 = cls(
             type=type,
+            flow=flow,
         )
 
         flow_module_value_2_type_7.additional_properties = d
