@@ -10,6 +10,8 @@ if TYPE_CHECKING:
     from ..models.forloop_flow_iterator_type_0 import ForloopFlowIteratorType0
     from ..models.forloop_flow_iterator_type_1 import ForloopFlowIteratorType1
     from ..models.forloop_flow_modules_item import ForloopFlowModulesItem
+    from ..models.forloop_flow_parallelism_type_0 import ForloopFlowParallelismType0
+    from ..models.forloop_flow_parallelism_type_1 import ForloopFlowParallelismType1
 
 
 T = TypeVar("T", bound="ForloopFlow")
@@ -24,7 +26,7 @@ class ForloopFlow:
         skip_failures (bool):
         type (ForloopFlowType):
         parallel (Union[Unset, bool]):
-        parallelism (Union[Unset, int]):
+        parallelism (Union['ForloopFlowParallelismType0', 'ForloopFlowParallelismType1', Unset]):
     """
 
     modules: List["ForloopFlowModulesItem"]
@@ -32,11 +34,12 @@ class ForloopFlow:
     skip_failures: bool
     type: ForloopFlowType
     parallel: Union[Unset, bool] = UNSET
-    parallelism: Union[Unset, int] = UNSET
+    parallelism: Union["ForloopFlowParallelismType0", "ForloopFlowParallelismType1", Unset] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         from ..models.forloop_flow_iterator_type_0 import ForloopFlowIteratorType0
+        from ..models.forloop_flow_parallelism_type_0 import ForloopFlowParallelismType0
 
         modules = []
         for modules_item_data in self.modules:
@@ -56,7 +59,19 @@ class ForloopFlow:
         type = self.type.value
 
         parallel = self.parallel
-        parallelism = self.parallelism
+        parallelism: Union[Dict[str, Any], Unset]
+        if isinstance(self.parallelism, Unset):
+            parallelism = UNSET
+
+        elif isinstance(self.parallelism, ForloopFlowParallelismType0):
+            parallelism = UNSET
+            if not isinstance(self.parallelism, Unset):
+                parallelism = self.parallelism.to_dict()
+
+        else:
+            parallelism = UNSET
+            if not isinstance(self.parallelism, Unset):
+                parallelism = self.parallelism.to_dict()
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -80,6 +95,8 @@ class ForloopFlow:
         from ..models.forloop_flow_iterator_type_0 import ForloopFlowIteratorType0
         from ..models.forloop_flow_iterator_type_1 import ForloopFlowIteratorType1
         from ..models.forloop_flow_modules_item import ForloopFlowModulesItem
+        from ..models.forloop_flow_parallelism_type_0 import ForloopFlowParallelismType0
+        from ..models.forloop_flow_parallelism_type_1 import ForloopFlowParallelismType1
 
         d = src_dict.copy()
         modules = []
@@ -112,7 +129,36 @@ class ForloopFlow:
 
         parallel = d.pop("parallel", UNSET)
 
-        parallelism = d.pop("parallelism", UNSET)
+        def _parse_parallelism(
+            data: object,
+        ) -> Union["ForloopFlowParallelismType0", "ForloopFlowParallelismType1", Unset]:
+            if isinstance(data, Unset):
+                return data
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                _parallelism_type_0 = data
+                parallelism_type_0: Union[Unset, ForloopFlowParallelismType0]
+                if isinstance(_parallelism_type_0, Unset):
+                    parallelism_type_0 = UNSET
+                else:
+                    parallelism_type_0 = ForloopFlowParallelismType0.from_dict(_parallelism_type_0)
+
+                return parallelism_type_0
+            except:  # noqa: E722
+                pass
+            if not isinstance(data, dict):
+                raise TypeError()
+            _parallelism_type_1 = data
+            parallelism_type_1: Union[Unset, ForloopFlowParallelismType1]
+            if isinstance(_parallelism_type_1, Unset):
+                parallelism_type_1 = UNSET
+            else:
+                parallelism_type_1 = ForloopFlowParallelismType1.from_dict(_parallelism_type_1)
+
+            return parallelism_type_1
+
+        parallelism = _parse_parallelism(d.pop("parallelism", UNSET))
 
         forloop_flow = cls(
             modules=modules,
