@@ -9,6 +9,7 @@ if TYPE_CHECKING:
     from ..models.get_completed_job_response_200_raw_flow_failure_module import (
         GetCompletedJobResponse200RawFlowFailureModule,
     )
+    from ..models.get_completed_job_response_200_raw_flow_flow_env import GetCompletedJobResponse200RawFlowFlowEnv
     from ..models.get_completed_job_response_200_raw_flow_modules_item import (
         GetCompletedJobResponse200RawFlowModulesItem,
     )
@@ -35,6 +36,7 @@ class GetCompletedJobResponse200RawFlow:
         debounce_key (Union[Unset, str]):
         skip_expr (Union[Unset, str]):
         cache_ttl (Union[Unset, float]):
+        flow_env (Union[Unset, GetCompletedJobResponse200RawFlowFlowEnv]):
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
@@ -51,6 +53,7 @@ class GetCompletedJobResponse200RawFlow:
     debounce_key: Union[Unset, str] = UNSET
     skip_expr: Union[Unset, str] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    flow_env: Union[Unset, "GetCompletedJobResponse200RawFlowFlowEnv"] = UNSET
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
@@ -79,6 +82,10 @@ class GetCompletedJobResponse200RawFlow:
         debounce_key = self.debounce_key
         skip_expr = self.skip_expr
         cache_ttl = self.cache_ttl
+        flow_env: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.flow_env, Unset):
+            flow_env = self.flow_env.to_dict()
+
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
@@ -110,6 +117,8 @@ class GetCompletedJobResponse200RawFlow:
             field_dict["skip_expr"] = skip_expr
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if flow_env is not UNSET:
+            field_dict["flow_env"] = flow_env
         if priority is not UNSET:
             field_dict["priority"] = priority
         if early_return is not UNSET:
@@ -124,6 +133,7 @@ class GetCompletedJobResponse200RawFlow:
         from ..models.get_completed_job_response_200_raw_flow_failure_module import (
             GetCompletedJobResponse200RawFlowFailureModule,
         )
+        from ..models.get_completed_job_response_200_raw_flow_flow_env import GetCompletedJobResponse200RawFlowFlowEnv
         from ..models.get_completed_job_response_200_raw_flow_modules_item import (
             GetCompletedJobResponse200RawFlowModulesItem,
         )
@@ -169,6 +179,13 @@ class GetCompletedJobResponse200RawFlow:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        _flow_env = d.pop("flow_env", UNSET)
+        flow_env: Union[Unset, GetCompletedJobResponse200RawFlowFlowEnv]
+        if isinstance(_flow_env, Unset):
+            flow_env = UNSET
+        else:
+            flow_env = GetCompletedJobResponse200RawFlowFlowEnv.from_dict(_flow_env)
+
         priority = d.pop("priority", UNSET)
 
         early_return = d.pop("early_return", UNSET)
@@ -187,6 +204,7 @@ class GetCompletedJobResponse200RawFlow:
             debounce_key=debounce_key,
             skip_expr=skip_expr,
             cache_ttl=cache_ttl,
+            flow_env=flow_env,
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
