@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -6,6 +6,7 @@ from attrs import field as _attrs_field
 from ..models.get_completed_job_response_200_raw_flow_failure_module_sleep_type_0_type import (
     GetCompletedJobResponse200RawFlowFailureModuleSleepType0Type,
 )
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="GetCompletedJobResponse200RawFlowFailureModuleSleepType0")
 
@@ -14,39 +15,41 @@ T = TypeVar("T", bound="GetCompletedJobResponse200RawFlowFailureModuleSleepType0
 class GetCompletedJobResponse200RawFlowFailureModuleSleepType0:
     """
     Attributes:
-        value (Any):
         type (GetCompletedJobResponse200RawFlowFailureModuleSleepType0Type):
+        value (Union[Unset, Any]):
     """
 
-    value: Any
     type: GetCompletedJobResponse200RawFlowFailureModuleSleepType0Type
+    value: Union[Unset, Any] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        value = self.value
         type = self.type.value
 
+        value = self.value
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
             {
-                "value": value,
                 "type": type,
             }
         )
+        if value is not UNSET:
+            field_dict["value"] = value
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        value = d.pop("value")
-
         type = GetCompletedJobResponse200RawFlowFailureModuleSleepType0Type(d.pop("type"))
 
+        value = d.pop("value", UNSET)
+
         get_completed_job_response_200_raw_flow_failure_module_sleep_type_0 = cls(
-            value=value,
             type=type,
+            value=value,
         )
 
         get_completed_job_response_200_raw_flow_failure_module_sleep_type_0.additional_properties = d
