@@ -10,7 +10,7 @@ T = TypeVar("T", bound="GetFlowByPathWithDraftResponse200DraftExtraPerms")
 class GetFlowByPathWithDraftResponse200DraftExtraPerms:
     """ """
 
-    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
+    additional_properties: Dict[str, bool] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         field_dict: Dict[str, Any] = {}
@@ -31,10 +31,10 @@ class GetFlowByPathWithDraftResponse200DraftExtraPerms:
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
 
-    def __getitem__(self, key: str) -> Any:
+    def __getitem__(self, key: str) -> bool:
         return self.additional_properties[key]
 
-    def __setitem__(self, key: str, value: Any) -> None:
+    def __setitem__(self, key: str, value: bool) -> None:
         self.additional_properties[key] = value
 
     def __delitem__(self, key: str) -> None:
