@@ -9,6 +9,7 @@ if TYPE_CHECKING:
     from ..models.list_queue_response_200_item_raw_flow_failure_module import (
         ListQueueResponse200ItemRawFlowFailureModule,
     )
+    from ..models.list_queue_response_200_item_raw_flow_flow_env import ListQueueResponse200ItemRawFlowFlowEnv
     from ..models.list_queue_response_200_item_raw_flow_modules_item import ListQueueResponse200ItemRawFlowModulesItem
     from ..models.list_queue_response_200_item_raw_flow_preprocessor_module import (
         ListQueueResponse200ItemRawFlowPreprocessorModule,
@@ -33,6 +34,7 @@ class ListQueueResponse200ItemRawFlow:
         debounce_key (Union[Unset, str]):
         skip_expr (Union[Unset, str]):
         cache_ttl (Union[Unset, float]):
+        flow_env (Union[Unset, ListQueueResponse200ItemRawFlowFlowEnv]):
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
@@ -49,6 +51,7 @@ class ListQueueResponse200ItemRawFlow:
     debounce_key: Union[Unset, str] = UNSET
     skip_expr: Union[Unset, str] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    flow_env: Union[Unset, "ListQueueResponse200ItemRawFlowFlowEnv"] = UNSET
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
@@ -77,6 +80,10 @@ class ListQueueResponse200ItemRawFlow:
         debounce_key = self.debounce_key
         skip_expr = self.skip_expr
         cache_ttl = self.cache_ttl
+        flow_env: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.flow_env, Unset):
+            flow_env = self.flow_env.to_dict()
+
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
@@ -108,6 +115,8 @@ class ListQueueResponse200ItemRawFlow:
             field_dict["skip_expr"] = skip_expr
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if flow_env is not UNSET:
+            field_dict["flow_env"] = flow_env
         if priority is not UNSET:
             field_dict["priority"] = priority
         if early_return is not UNSET:
@@ -122,6 +131,7 @@ class ListQueueResponse200ItemRawFlow:
         from ..models.list_queue_response_200_item_raw_flow_failure_module import (
             ListQueueResponse200ItemRawFlowFailureModule,
         )
+        from ..models.list_queue_response_200_item_raw_flow_flow_env import ListQueueResponse200ItemRawFlowFlowEnv
         from ..models.list_queue_response_200_item_raw_flow_modules_item import (
             ListQueueResponse200ItemRawFlowModulesItem,
         )
@@ -167,6 +177,13 @@ class ListQueueResponse200ItemRawFlow:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        _flow_env = d.pop("flow_env", UNSET)
+        flow_env: Union[Unset, ListQueueResponse200ItemRawFlowFlowEnv]
+        if isinstance(_flow_env, Unset):
+            flow_env = UNSET
+        else:
+            flow_env = ListQueueResponse200ItemRawFlowFlowEnv.from_dict(_flow_env)
+
         priority = d.pop("priority", UNSET)
 
         early_return = d.pop("early_return", UNSET)
@@ -185,6 +202,7 @@ class ListQueueResponse200ItemRawFlow:
             debounce_key=debounce_key,
             skip_expr=skip_expr,
             cache_ttl=cache_ttl,
+            flow_env=flow_env,
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
