@@ -1,8 +1,10 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
+from ..types import UNSET, Unset
+
 T = TypeVar("T", bound="ListWorkspaceInvitesResponse200Item")
 
 
@@ -14,12 +16,14 @@ class ListWorkspaceInvitesResponse200Item:
         email (str):
         is_admin (bool):
         operator (bool):
+        parent_workspace_id (Union[Unset, None, str]):
     """
 
     workspace_id: str
     email: str
     is_admin: bool
     operator: bool
+    parent_workspace_id: Union[Unset, None, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -27,6 +31,7 @@ class ListWorkspaceInvitesResponse200Item:
         email = self.email
         is_admin = self.is_admin
         operator = self.operator
+        parent_workspace_id = self.parent_workspace_id
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -38,6 +43,8 @@ class ListWorkspaceInvitesResponse200Item:
                 "operator": operator,
             }
         )
+        if parent_workspace_id is not UNSET:
+            field_dict["parent_workspace_id"] = parent_workspace_id
 
         return field_dict
 
@@ -52,11 +59,14 @@ class ListWorkspaceInvitesResponse200Item:
 
         operator = d.pop("operator")
 
+        parent_workspace_id = d.pop("parent_workspace_id", UNSET)
+
         list_workspace_invites_response_200_item = cls(
             workspace_id=workspace_id,
             email=email,
             is_admin=is_admin,
             operator=operator,
+            parent_workspace_id=parent_workspace_id,
         )
 
         list_workspace_invites_response_200_item.additional_properties = d
