@@ -27,7 +27,7 @@ class NewNatsTrigger:
         consumer_name (Union[Unset, str]):
         enabled (Union[Unset, bool]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, NewNatsTriggerErrorHandlerArgs]):
+        error_handler_args (Union[Unset, NewNatsTriggerErrorHandlerArgs]): The arguments to pass to the script or flow
         retry (Union[Unset, NewNatsTriggerRetry]):
     """
 
