@@ -17,11 +17,13 @@ class NewTokenImpersonate:
         impersonate_email (str):
         label (Union[Unset, str]):
         expiration (Union[Unset, datetime.datetime]):
+        workspace_id (Union[Unset, str]):
     """
 
     impersonate_email: str
     label: Union[Unset, str] = UNSET
     expiration: Union[Unset, datetime.datetime] = UNSET
+    workspace_id: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -31,6 +33,8 @@ class NewTokenImpersonate:
         if not isinstance(self.expiration, Unset):
             expiration = self.expiration.isoformat()
 
+        workspace_id = self.workspace_id
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -42,6 +46,8 @@ class NewTokenImpersonate:
             field_dict["label"] = label
         if expiration is not UNSET:
             field_dict["expiration"] = expiration
+        if workspace_id is not UNSET:
+            field_dict["workspace_id"] = workspace_id
 
         return field_dict
 
@@ -59,10 +65,13 @@ class NewTokenImpersonate:
         else:
             expiration = isoparse(_expiration)
 
+        workspace_id = d.pop("workspace_id", UNSET)
+
         new_token_impersonate = cls(
             impersonate_email=impersonate_email,
             label=label,
             expiration=expiration,
+            workspace_id=workspace_id,
         )
 
         new_token_impersonate.additional_properties = d
