@@ -13,6 +13,9 @@ if TYPE_CHECKING:
     from ..models.queued_job_flow_status_failure_module_agent_actions_item_type_1 import (
         QueuedJobFlowStatusFailureModuleAgentActionsItemType1,
     )
+    from ..models.queued_job_flow_status_failure_module_agent_actions_item_type_2 import (
+        QueuedJobFlowStatusFailureModuleAgentActionsItemType2,
+    )
     from ..models.queued_job_flow_status_failure_module_approvers_item import (
         QueuedJobFlowStatusFailureModuleApproversItem,
     )
@@ -48,7 +51,8 @@ class QueuedJobFlowStatusFailureModule:
         failed_retries (Union[Unset, List[str]]):
         skipped (Union[Unset, bool]):
         agent_actions (Union[Unset, List[Union['QueuedJobFlowStatusFailureModuleAgentActionsItemType0',
-            'QueuedJobFlowStatusFailureModuleAgentActionsItemType1']]]):
+            'QueuedJobFlowStatusFailureModuleAgentActionsItemType1',
+            'QueuedJobFlowStatusFailureModuleAgentActionsItemType2']]]):
         agent_actions_success (Union[Unset, List[bool]]):
         parent_module (Union[Unset, str]):
     """
@@ -73,6 +77,7 @@ class QueuedJobFlowStatusFailureModule:
             Union[
                 "QueuedJobFlowStatusFailureModuleAgentActionsItemType0",
                 "QueuedJobFlowStatusFailureModuleAgentActionsItemType1",
+                "QueuedJobFlowStatusFailureModuleAgentActionsItemType2",
             ]
         ],
     ] = UNSET
@@ -84,6 +89,9 @@ class QueuedJobFlowStatusFailureModule:
         from ..models.queued_job_flow_status_failure_module_agent_actions_item_type_0 import (
             QueuedJobFlowStatusFailureModuleAgentActionsItemType0,
         )
+        from ..models.queued_job_flow_status_failure_module_agent_actions_item_type_1 import (
+            QueuedJobFlowStatusFailureModuleAgentActionsItemType1,
+        )
 
         type = self.type.value
 
@@ -137,6 +145,9 @@ class QueuedJobFlowStatusFailureModule:
                 if isinstance(agent_actions_item_data, QueuedJobFlowStatusFailureModuleAgentActionsItemType0):
                     agent_actions_item = agent_actions_item_data.to_dict()
 
+                elif isinstance(agent_actions_item_data, QueuedJobFlowStatusFailureModuleAgentActionsItemType1):
+                    agent_actions_item = agent_actions_item_data.to_dict()
+
                 else:
                     agent_actions_item = agent_actions_item_data.to_dict()
 
@@ -198,6 +209,9 @@ class QueuedJobFlowStatusFailureModule:
         from ..models.queued_job_flow_status_failure_module_agent_actions_item_type_1 import (
             QueuedJobFlowStatusFailureModuleAgentActionsItemType1,
         )
+        from ..models.queued_job_flow_status_failure_module_agent_actions_item_type_2 import (
+            QueuedJobFlowStatusFailureModuleAgentActionsItemType2,
+        )
         from ..models.queued_job_flow_status_failure_module_approvers_item import (
             QueuedJobFlowStatusFailureModuleApproversItem,
         )
@@ -273,6 +287,7 @@ class QueuedJobFlowStatusFailureModule:
             ) -> Union[
                 "QueuedJobFlowStatusFailureModuleAgentActionsItemType0",
                 "QueuedJobFlowStatusFailureModuleAgentActionsItemType1",
+                "QueuedJobFlowStatusFailureModuleAgentActionsItemType2",
             ]:
                 try:
                     if not isinstance(data, dict):
@@ -282,11 +297,19 @@ class QueuedJobFlowStatusFailureModule:
                     return agent_actions_item_type_0
                 except:  # noqa: E722
                     pass
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    agent_actions_item_type_1 = QueuedJobFlowStatusFailureModuleAgentActionsItemType1.from_dict(data)
+
+                    return agent_actions_item_type_1
+                except:  # noqa: E722
+                    pass
                 if not isinstance(data, dict):
                     raise TypeError()
-                agent_actions_item_type_1 = QueuedJobFlowStatusFailureModuleAgentActionsItemType1.from_dict(data)
+                agent_actions_item_type_2 = QueuedJobFlowStatusFailureModuleAgentActionsItemType2.from_dict(data)
 
-                return agent_actions_item_type_1
+                return agent_actions_item_type_2
 
             agent_actions_item = _parse_agent_actions_item(agent_actions_item_data)
 
