@@ -13,6 +13,9 @@ if TYPE_CHECKING:
     from ..models.queued_job_flow_status_modules_item_agent_actions_item_type_1 import (
         QueuedJobFlowStatusModulesItemAgentActionsItemType1,
     )
+    from ..models.queued_job_flow_status_modules_item_agent_actions_item_type_2 import (
+        QueuedJobFlowStatusModulesItemAgentActionsItemType2,
+    )
     from ..models.queued_job_flow_status_modules_item_approvers_item import QueuedJobFlowStatusModulesItemApproversItem
     from ..models.queued_job_flow_status_modules_item_branch_chosen import QueuedJobFlowStatusModulesItemBranchChosen
     from ..models.queued_job_flow_status_modules_item_branchall import QueuedJobFlowStatusModulesItemBranchall
@@ -44,7 +47,8 @@ class QueuedJobFlowStatusModulesItem:
         failed_retries (Union[Unset, List[str]]):
         skipped (Union[Unset, bool]):
         agent_actions (Union[Unset, List[Union['QueuedJobFlowStatusModulesItemAgentActionsItemType0',
-            'QueuedJobFlowStatusModulesItemAgentActionsItemType1']]]):
+            'QueuedJobFlowStatusModulesItemAgentActionsItemType1',
+            'QueuedJobFlowStatusModulesItemAgentActionsItemType2']]]):
         agent_actions_success (Union[Unset, List[bool]]):
     """
 
@@ -68,6 +72,7 @@ class QueuedJobFlowStatusModulesItem:
             Union[
                 "QueuedJobFlowStatusModulesItemAgentActionsItemType0",
                 "QueuedJobFlowStatusModulesItemAgentActionsItemType1",
+                "QueuedJobFlowStatusModulesItemAgentActionsItemType2",
             ]
         ],
     ] = UNSET
@@ -78,6 +83,9 @@ class QueuedJobFlowStatusModulesItem:
         from ..models.queued_job_flow_status_modules_item_agent_actions_item_type_0 import (
             QueuedJobFlowStatusModulesItemAgentActionsItemType0,
         )
+        from ..models.queued_job_flow_status_modules_item_agent_actions_item_type_1 import (
+            QueuedJobFlowStatusModulesItemAgentActionsItemType1,
+        )
 
         type = self.type.value
 
@@ -131,6 +139,9 @@ class QueuedJobFlowStatusModulesItem:
                 if isinstance(agent_actions_item_data, QueuedJobFlowStatusModulesItemAgentActionsItemType0):
                     agent_actions_item = agent_actions_item_data.to_dict()
 
+                elif isinstance(agent_actions_item_data, QueuedJobFlowStatusModulesItemAgentActionsItemType1):
+                    agent_actions_item = agent_actions_item_data.to_dict()
+
                 else:
                     agent_actions_item = agent_actions_item_data.to_dict()
 
@@ -188,6 +199,9 @@ class QueuedJobFlowStatusModulesItem:
         from ..models.queued_job_flow_status_modules_item_agent_actions_item_type_1 import (
             QueuedJobFlowStatusModulesItemAgentActionsItemType1,
         )
+        from ..models.queued_job_flow_status_modules_item_agent_actions_item_type_2 import (
+            QueuedJobFlowStatusModulesItemAgentActionsItemType2,
+        )
         from ..models.queued_job_flow_status_modules_item_approvers_item import (
             QueuedJobFlowStatusModulesItemApproversItem,
         )
@@ -263,6 +277,7 @@ class QueuedJobFlowStatusModulesItem:
             ) -> Union[
                 "QueuedJobFlowStatusModulesItemAgentActionsItemType0",
                 "QueuedJobFlowStatusModulesItemAgentActionsItemType1",
+                "QueuedJobFlowStatusModulesItemAgentActionsItemType2",
             ]:
                 try:
                     if not isinstance(data, dict):
@@ -272,11 +287,19 @@ class QueuedJobFlowStatusModulesItem:
                     return agent_actions_item_type_0
                 except:  # noqa: E722
                     pass
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    agent_actions_item_type_1 = QueuedJobFlowStatusModulesItemAgentActionsItemType1.from_dict(data)
+
+                    return agent_actions_item_type_1
+                except:  # noqa: E722
+                    pass
                 if not isinstance(data, dict):
                     raise TypeError()
-                agent_actions_item_type_1 = QueuedJobFlowStatusModulesItemAgentActionsItemType1.from_dict(data)
+                agent_actions_item_type_2 = QueuedJobFlowStatusModulesItemAgentActionsItemType2.from_dict(data)
 
-                return agent_actions_item_type_1
+                return agent_actions_item_type_2
 
             agent_actions_item = _parse_agent_actions_item(agent_actions_item_data)
 
