@@ -7,6 +7,7 @@ from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.queued_job_raw_flow_failure_module import QueuedJobRawFlowFailureModule
+    from ..models.queued_job_raw_flow_flow_env import QueuedJobRawFlowFlowEnv
     from ..models.queued_job_raw_flow_modules_item import QueuedJobRawFlowModulesItem
     from ..models.queued_job_raw_flow_preprocessor_module import QueuedJobRawFlowPreprocessorModule
 
@@ -29,6 +30,7 @@ class QueuedJobRawFlow:
         debounce_key (Union[Unset, str]):
         skip_expr (Union[Unset, str]):
         cache_ttl (Union[Unset, float]):
+        flow_env (Union[Unset, QueuedJobRawFlowFlowEnv]):
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
@@ -45,6 +47,7 @@ class QueuedJobRawFlow:
     debounce_key: Union[Unset, str] = UNSET
     skip_expr: Union[Unset, str] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    flow_env: Union[Unset, "QueuedJobRawFlowFlowEnv"] = UNSET
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
@@ -73,6 +76,10 @@ class QueuedJobRawFlow:
         debounce_key = self.debounce_key
         skip_expr = self.skip_expr
         cache_ttl = self.cache_ttl
+        flow_env: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.flow_env, Unset):
+            flow_env = self.flow_env.to_dict()
+
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
@@ -104,6 +111,8 @@ class QueuedJobRawFlow:
             field_dict["skip_expr"] = skip_expr
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if flow_env is not UNSET:
+            field_dict["flow_env"] = flow_env
         if priority is not UNSET:
             field_dict["priority"] = priority
         if early_return is not UNSET:
@@ -116,6 +125,7 @@ class QueuedJobRawFlow:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.queued_job_raw_flow_failure_module import QueuedJobRawFlowFailureModule
+        from ..models.queued_job_raw_flow_flow_env import QueuedJobRawFlowFlowEnv
         from ..models.queued_job_raw_flow_modules_item import QueuedJobRawFlowModulesItem
         from ..models.queued_job_raw_flow_preprocessor_module import QueuedJobRawFlowPreprocessorModule
 
@@ -157,6 +167,13 @@ class QueuedJobRawFlow:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        _flow_env = d.pop("flow_env", UNSET)
+        flow_env: Union[Unset, QueuedJobRawFlowFlowEnv]
+        if isinstance(_flow_env, Unset):
+            flow_env = UNSET
+        else:
+            flow_env = QueuedJobRawFlowFlowEnv.from_dict(_flow_env)
+
         priority = d.pop("priority", UNSET)
 
         early_return = d.pop("early_return", UNSET)
@@ -175,6 +192,7 @@ class QueuedJobRawFlow:
             debounce_key=debounce_key,
             skip_expr=skip_expr,
             cache_ttl=cache_ttl,
+            flow_env=flow_env,
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
