@@ -7,6 +7,7 @@ from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.run_flow_preview_json_body_value_failure_module import RunFlowPreviewJsonBodyValueFailureModule
+    from ..models.run_flow_preview_json_body_value_flow_env import RunFlowPreviewJsonBodyValueFlowEnv
     from ..models.run_flow_preview_json_body_value_modules_item import RunFlowPreviewJsonBodyValueModulesItem
     from ..models.run_flow_preview_json_body_value_preprocessor_module import (
         RunFlowPreviewJsonBodyValuePreprocessorModule,
@@ -31,6 +32,7 @@ class RunFlowPreviewJsonBodyValue:
         debounce_key (Union[Unset, str]):
         skip_expr (Union[Unset, str]):
         cache_ttl (Union[Unset, float]):
+        flow_env (Union[Unset, RunFlowPreviewJsonBodyValueFlowEnv]):
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
@@ -47,6 +49,7 @@ class RunFlowPreviewJsonBodyValue:
     debounce_key: Union[Unset, str] = UNSET
     skip_expr: Union[Unset, str] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    flow_env: Union[Unset, "RunFlowPreviewJsonBodyValueFlowEnv"] = UNSET
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
@@ -75,6 +78,10 @@ class RunFlowPreviewJsonBodyValue:
         debounce_key = self.debounce_key
         skip_expr = self.skip_expr
         cache_ttl = self.cache_ttl
+        flow_env: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.flow_env, Unset):
+            flow_env = self.flow_env.to_dict()
+
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
@@ -106,6 +113,8 @@ class RunFlowPreviewJsonBodyValue:
             field_dict["skip_expr"] = skip_expr
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if flow_env is not UNSET:
+            field_dict["flow_env"] = flow_env
         if priority is not UNSET:
             field_dict["priority"] = priority
         if early_return is not UNSET:
@@ -118,6 +127,7 @@ class RunFlowPreviewJsonBodyValue:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.run_flow_preview_json_body_value_failure_module import RunFlowPreviewJsonBodyValueFailureModule
+        from ..models.run_flow_preview_json_body_value_flow_env import RunFlowPreviewJsonBodyValueFlowEnv
         from ..models.run_flow_preview_json_body_value_modules_item import RunFlowPreviewJsonBodyValueModulesItem
         from ..models.run_flow_preview_json_body_value_preprocessor_module import (
             RunFlowPreviewJsonBodyValuePreprocessorModule,
@@ -161,6 +171,13 @@ class RunFlowPreviewJsonBodyValue:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        _flow_env = d.pop("flow_env", UNSET)
+        flow_env: Union[Unset, RunFlowPreviewJsonBodyValueFlowEnv]
+        if isinstance(_flow_env, Unset):
+            flow_env = UNSET
+        else:
+            flow_env = RunFlowPreviewJsonBodyValueFlowEnv.from_dict(_flow_env)
+
         priority = d.pop("priority", UNSET)
 
         early_return = d.pop("early_return", UNSET)
@@ -179,6 +196,7 @@ class RunFlowPreviewJsonBodyValue:
             debounce_key=debounce_key,
             skip_expr=skip_expr,
             cache_ttl=cache_ttl,
+            flow_env=flow_env,
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
