@@ -26,6 +26,12 @@ if TYPE_CHECKING:
     from ..models.run_flow_preview_json_body_value_modules_item_suspend import (
         RunFlowPreviewJsonBodyValueModulesItemSuspend,
     )
+    from ..models.run_flow_preview_json_body_value_modules_item_timeout_type_0 import (
+        RunFlowPreviewJsonBodyValueModulesItemTimeoutType0,
+    )
+    from ..models.run_flow_preview_json_body_value_modules_item_timeout_type_1 import (
+        RunFlowPreviewJsonBodyValueModulesItemTimeoutType1,
+    )
 
 
 T = TypeVar("T", bound="RunFlowPreviewJsonBodyValueModulesItem")
@@ -43,7 +49,8 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         sleep (Union['RunFlowPreviewJsonBodyValueModulesItemSleepType0',
             'RunFlowPreviewJsonBodyValueModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
-        timeout (Union[Unset, float]):
+        timeout (Union['RunFlowPreviewJsonBodyValueModulesItemTimeoutType0',
+            'RunFlowPreviewJsonBodyValueModulesItemTimeoutType1', Unset]):
         delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, RunFlowPreviewJsonBodyValueModulesItemMock]):
@@ -62,7 +69,11 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         "RunFlowPreviewJsonBodyValueModulesItemSleepType0", "RunFlowPreviewJsonBodyValueModulesItemSleepType1", Unset
     ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
-    timeout: Union[Unset, float] = UNSET
+    timeout: Union[
+        "RunFlowPreviewJsonBodyValueModulesItemTimeoutType0",
+        "RunFlowPreviewJsonBodyValueModulesItemTimeoutType1",
+        Unset,
+    ] = UNSET
     delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
     mock: Union[Unset, "RunFlowPreviewJsonBodyValueModulesItemMock"] = UNSET
@@ -76,6 +87,9 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_0 import (
             RunFlowPreviewJsonBodyValueModulesItemSleepType0,
         )
+        from ..models.run_flow_preview_json_body_value_modules_item_timeout_type_0 import (
+            RunFlowPreviewJsonBodyValueModulesItemTimeoutType0,
+        )
 
         id = self.id
         value = self.value
@@ -106,7 +120,20 @@ class RunFlowPreviewJsonBodyValueModulesItem:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
-        timeout = self.timeout
+        timeout: Union[Dict[str, Any], Unset]
+        if isinstance(self.timeout, Unset):
+            timeout = UNSET
+
+        elif isinstance(self.timeout, RunFlowPreviewJsonBodyValueModulesItemTimeoutType0):
+            timeout = UNSET
+            if not isinstance(self.timeout, Unset):
+                timeout = self.timeout.to_dict()
+
+        else:
+            timeout = UNSET
+            if not isinstance(self.timeout, Unset):
+                timeout = self.timeout.to_dict()
+
         delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
@@ -186,6 +213,12 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         from ..models.run_flow_preview_json_body_value_modules_item_suspend import (
             RunFlowPreviewJsonBodyValueModulesItemSuspend,
         )
+        from ..models.run_flow_preview_json_body_value_modules_item_timeout_type_0 import (
+            RunFlowPreviewJsonBodyValueModulesItemTimeoutType0,
+        )
+        from ..models.run_flow_preview_json_body_value_modules_item_timeout_type_1 import (
+            RunFlowPreviewJsonBodyValueModulesItemTimeoutType1,
+        )
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -252,7 +285,40 @@ class RunFlowPreviewJsonBodyValueModulesItem:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
-        timeout = d.pop("timeout", UNSET)
+        def _parse_timeout(
+            data: object,
+        ) -> Union[
+            "RunFlowPreviewJsonBodyValueModulesItemTimeoutType0",
+            "RunFlowPreviewJsonBodyValueModulesItemTimeoutType1",
+            Unset,
+        ]:
+            if isinstance(data, Unset):
+                return data
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                _timeout_type_0 = data
+                timeout_type_0: Union[Unset, RunFlowPreviewJsonBodyValueModulesItemTimeoutType0]
+                if isinstance(_timeout_type_0, Unset):
+                    timeout_type_0 = UNSET
+                else:
+                    timeout_type_0 = RunFlowPreviewJsonBodyValueModulesItemTimeoutType0.from_dict(_timeout_type_0)
+
+                return timeout_type_0
+            except:  # noqa: E722
+                pass
+            if not isinstance(data, dict):
+                raise TypeError()
+            _timeout_type_1 = data
+            timeout_type_1: Union[Unset, RunFlowPreviewJsonBodyValueModulesItemTimeoutType1]
+            if isinstance(_timeout_type_1, Unset):
+                timeout_type_1 = UNSET
+            else:
+                timeout_type_1 = RunFlowPreviewJsonBodyValueModulesItemTimeoutType1.from_dict(_timeout_type_1)
+
+            return timeout_type_1
+
+        timeout = _parse_timeout(d.pop("timeout", UNSET))
 
         delete_after_use = d.pop("delete_after_use", UNSET)
 
