@@ -56,6 +56,8 @@ class ScheduleWJobs:
         tag (Union[Unset, str]):
         paused_until (Union[Unset, datetime.datetime]):
         cron_version (Union[Unset, str]):
+        dynamic_skip (Union[Unset, str]): Path to a script that validates scheduled datetimes. Receives scheduled_for
+            datetime and returns boolean.
         jobs (Union[Unset, List['ScheduleWJobsJobsItem']]):
     """
 
@@ -88,6 +90,7 @@ class ScheduleWJobs:
     tag: Union[Unset, str] = UNSET
     paused_until: Union[Unset, datetime.datetime] = UNSET
     cron_version: Union[Unset, str] = UNSET
+    dynamic_skip: Union[Unset, str] = UNSET
     jobs: Union[Unset, List["ScheduleWJobsJobsItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -141,6 +144,7 @@ class ScheduleWJobs:
             paused_until = self.paused_until.isoformat()
 
         cron_version = self.cron_version
+        dynamic_skip = self.dynamic_skip
         jobs: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.jobs, Unset):
             jobs = []
@@ -203,6 +207,8 @@ class ScheduleWJobs:
             field_dict["paused_until"] = paused_until
         if cron_version is not UNSET:
             field_dict["cron_version"] = cron_version
+        if dynamic_skip is not UNSET:
+            field_dict["dynamic_skip"] = dynamic_skip
         if jobs is not UNSET:
             field_dict["jobs"] = jobs
 
@@ -307,6 +313,8 @@ class ScheduleWJobs:
 
         cron_version = d.pop("cron_version", UNSET)
 
+        dynamic_skip = d.pop("dynamic_skip", UNSET)
+
         jobs = []
         _jobs = d.pop("jobs", UNSET)
         for jobs_item_data in _jobs or []:
@@ -344,6 +352,7 @@ class ScheduleWJobs:
             tag=tag,
             paused_until=paused_until,
             cron_version=cron_version,
+            dynamic_skip=dynamic_skip,
             jobs=jobs,
         )
 
